@@ -18,6 +18,7 @@
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """This module contains an object that represents a Telegram ChatFullInfo."""
+
 import datetime as dtm
 from collections.abc import Sequence
 from typing import TYPE_CHECKING, Optional, Union
@@ -223,6 +224,14 @@ class ChatFullInfo(_ChatBase):
             sent or forwarded to the channel chat. The field is available only for channel chats.
 
             .. versionadded:: 21.4
+        is_direct_messages (:obj:`bool`, optional): :obj:`True`, if the chat is the direct messages
+            chat of a channel.
+
+            .. versionadded:: 22.4
+        parent_chat (:obj:`telegram.Chat`, optional): Information about the corresponding channel
+            chat; for direct messages chats only.
+
+            .. versionadded:: 22.4
 
     Attributes:
         id (:obj:`int`): Unique identifier for this chat.
@@ -387,6 +396,14 @@ class ChatFullInfo(_ChatBase):
             sent or forwarded to the channel chat. The field is available only for channel chats.
 
             .. versionadded:: 21.4
+        is_direct_messages (:obj:`bool`): Optional. :obj:`True`, if the chat is the direct messages
+            chat of a channel.
+
+            .. versionadded:: 22.4
+        parent_chat (:obj:`telegram.Chat`): Optional. Information about the corresponding channel
+            chat; for direct messages chats only.
+
+            .. versionadded:: 22.4
 
     .. _accent colors: https://core.telegram.org/bots/api#accent-colors
     .. _topics: https://telegram.org/blog/topics-in-groups-collectible-usernames#topics-in-groups
@@ -423,6 +440,7 @@ class ChatFullInfo(_ChatBase):
         "linked_chat_id",
         "location",
         "max_reaction_count",
+        "parent_chat",
         "permissions",
         "personal_chat",
         "photo",
@@ -480,6 +498,8 @@ class ChatFullInfo(_ChatBase):
         linked_chat_id: Optional[int] = None,
         location: Optional[ChatLocation] = None,
         can_send_paid_media: Optional[bool] = None,
+        is_direct_messages: Optional[bool] = None,
+        parent_chat: Optional[Chat] = None,
         *,
         api_kwargs: Optional[JSONDict] = None,
     ):
@@ -491,6 +511,7 @@ class ChatFullInfo(_ChatBase):
             first_name=first_name,
             last_name=last_name,
             is_forum=is_forum,
+            is_direct_messages=is_direct_messages,
             api_kwargs=api_kwargs,
         )
         # Required and unique to this class-
@@ -545,6 +566,7 @@ class ChatFullInfo(_ChatBase):
             self.business_opening_hours: Optional[BusinessOpeningHours] = business_opening_hours
             self.can_send_paid_media: Optional[bool] = can_send_paid_media
             self.accepted_gift_types: AcceptedGiftTypes = accepted_gift_types
+            self.parent_chat: Optional[Chat] = parent_chat
 
     @property
     def slow_mode_delay(self) -> Optional[Union[int, dtm.timedelta]]:
@@ -595,5 +617,6 @@ class ChatFullInfo(_ChatBase):
         data["business_opening_hours"] = de_json_optional(
             data.get("business_opening_hours"), BusinessOpeningHours, bot
         )
+        data["parent_chat"] = de_json_optional(data.get("parent_chat"), Chat, bot)
 
         return super().de_json(data=data, bot=bot)
