@@ -17,6 +17,7 @@
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 import asyncio
+import datetime as dtm
 import os
 from pathlib import Path
 
@@ -27,6 +28,7 @@ from telegram.constants import ParseMode
 from telegram.error import BadRequest, TelegramError
 from telegram.helpers import escape_markdown
 from telegram.request import RequestData
+from telegram.warnings import PTBDeprecationWarning
 from tests.auxil.bot_method_checks import (
     check_defaults_handling,
     check_shortcut_call,
@@ -42,7 +44,7 @@ class AnimationTestBase:
     animation_file_unique_id = "adc3145fd2e84d95b64d68eaa22aa33e"
     width = 320
     height = 180
-    duration = 1
+    duration = dtm.timedelta(seconds=1)
     # animation_file_url = 'https://python-telegram-bot.org/static/testfiles/game.gif'
     # Shortened link, the above one is cached with the wrong duration.
     animation_file_url = "http://bit.ly/2L18jua"
@@ -76,7 +78,7 @@ class TestAnimationWithoutRequest(AnimationTestBase):
             "file_unique_id": self.animation_file_unique_id,
             "width": self.width,
             "height": self.height,
-            "duration": self.duration,
+            "duration": self.duration.total_seconds(),
             "thumbnail": animation.thumbnail.to_dict(),
             "file_name": self.file_name,
             "mime_type": self.mime_type,
@@ -89,6 +91,7 @@ class TestAnimationWithoutRequest(AnimationTestBase):
         assert animation.file_name == self.file_name
         assert animation.mime_type == self.mime_type
         assert animation.file_size == self.file_size
+        assert animation._duration == self.duration
 
     def test_to_dict(self, animation):
         animation_dict = animation.to_dict()
@@ -98,12 +101,31 @@ class TestAnimationWithoutRequest(AnimationTestBase):
         assert animation_dict["file_unique_id"] == animation.file_unique_id
         assert animation_dict["width"] == animation.width
         assert animation_dict["height"] == animation.height
-        assert animation_dict["duration"] == animation.duration
+        assert animation_dict["duration"] == int(self.duration.total_seconds())
+        assert isinstance(animation_dict["duration"], int)
         assert animation_dict["thumbnail"] == animation.thumbnail.to_dict()
         assert animation_dict["file_name"] == animation.file_name
         assert animation_dict["mime_type"] == animation.mime_type
         assert animation_dict["file_size"] == animation.file_size
 
+    def test_time_period_properties(self, PTB_TIMEDELTA, animation):
+        if PTB_TIMEDELTA:
+            assert animation.duration == self.duration
+            assert isinstance(animation.duration, dtm.timedelta)
+        else:
+            assert animation.duration == int(self.duration.total_seconds())
+            assert isinstance(animation.duration, int)
+
+    def test_time_period_int_deprecated(self, recwarn, PTB_TIMEDELTA, animation):
+        animation.duration
+
+        if PTB_TIMEDELTA:
+            assert len(recwarn) == 0
+        else:
+            assert len(recwarn) == 1
+            assert "`duration` will be of type `datetime.timedelta`" in str(recwarn[0].message)
+            assert recwarn[0].category is PTBDeprecationWarning
+
     def test_equality(self):
         a = Animation(
             self.animation_file_id,
@@ -138,7 +160,9 @@ class TestAnimationWithoutRequest(AnimationTestBase):
         )
 
     @pytest.mark.parametrize("local_mode", [True, False])
-    async def test_send_animation_local_files(self, monkeypatch, offline_bot, chat_id, local_mode):
+    async def test_send_animation_local_files(
+        self, monkeypatch, offline_bot, chat_id, local_mode, dummy_message_dict
+    ):
         try:
             offline_bot._local_mode = local_mode
             # For just test that the correct paths are passed as we have no local Bot API set up
@@ -156,6 +180,7 @@ class TestAnimationWithoutRequest(AnimationTestBase):
                     test_flag = isinstance(data.get("animation"), InputFile) and isinstance(
                         data.get("thumbnail"), InputFile
                     )
+                return dummy_message_dict
 
             monkeypatch.setattr(offline_bot, "_post", make_assertion)
             await offline_bot.send_animation(chat_id, file, thumbnail=file)
@@ -210,11 +235,14 @@ class TestAnimationWithoutRequest(AnimationTestBase):
 
 
 class TestAnimationWithRequest(AnimationTestBase):
-    async def test_send_all_args(self, bot, chat_id, animation_file, animation, thumb_file):
+    @pytest.mark.parametrize("duration", [1, dtm.timedelta(seconds=1)])
+    async def test_send_all_args(
+        self, bot, chat_id, animation_file, animation, thumb_file, duration
+    ):
         message = await bot.send_animation(
             chat_id,
             animation_file,
-            duration=self.duration,
+            duration=duration,
             width=self.width,
             height=self.height,
             caption=self.caption,
