@@ -17,6 +17,7 @@
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 import asyncio
+import datetime as dtm
 import os
 from pathlib import Path
 
@@ -27,6 +28,7 @@ from telegram.constants import ParseMode
 from telegram.error import BadRequest, TelegramError
 from telegram.helpers import escape_markdown
 from telegram.request import RequestData
+from telegram.warnings import PTBDeprecationWarning
 from tests.auxil.bot_method_checks import (
     check_defaults_handling,
     check_shortcut_call,
@@ -42,7 +44,7 @@ class AudioTestBase:
     performer = "Leandro Toledo"
     title = "Teste"
     file_name = "telegram.mp3"
-    duration = 3
+    duration = dtm.timedelta(seconds=3)
     # audio_file_url = 'https://python-telegram-bot.org/static/testfiles/telegram.mp3'
     # Shortened link, the above one is cached with the wrong duration.
     audio_file_url = "https://goo.gl/3En24v"
@@ -70,7 +72,7 @@ class TestAudioWithoutRequest(AudioTestBase):
         assert audio.file_unique_id
 
     def test_expected_values(self, audio):
-        assert audio.duration == self.duration
+        assert audio._duration == self.duration
         assert audio.performer is None
         assert audio.title is None
         assert audio.mime_type == self.mime_type
@@ -83,7 +85,7 @@ class TestAudioWithoutRequest(AudioTestBase):
         json_dict = {
             "file_id": self.audio_file_id,
             "file_unique_id": self.audio_file_unique_id,
-            "duration": self.duration,
+            "duration": int(self.duration.total_seconds()),
             "performer": self.performer,
             "title": self.title,
             "file_name": self.file_name,
@@ -96,7 +98,7 @@ class TestAudioWithoutRequest(AudioTestBase):
 
         assert json_audio.file_id == self.audio_file_id
         assert json_audio.file_unique_id == self.audio_file_unique_id
-        assert json_audio.duration == self.duration
+        assert json_audio._duration == self.duration
         assert json_audio.performer == self.performer
         assert json_audio.title == self.title
         assert json_audio.file_name == self.file_name
@@ -110,11 +112,30 @@ class TestAudioWithoutRequest(AudioTestBase):
         assert isinstance(audio_dict, dict)
         assert audio_dict["file_id"] == audio.file_id
         assert audio_dict["file_unique_id"] == audio.file_unique_id
-        assert audio_dict["duration"] == audio.duration
+        assert audio_dict["duration"] == int(self.duration.total_seconds())
+        assert isinstance(audio_dict["duration"], int)
         assert audio_dict["mime_type"] == audio.mime_type
         assert audio_dict["file_size"] == audio.file_size
         assert audio_dict["file_name"] == audio.file_name
 
+    def test_time_period_properties(self, PTB_TIMEDELTA, audio):
+        if PTB_TIMEDELTA:
+            assert audio.duration == self.duration
+            assert isinstance(audio.duration, dtm.timedelta)
+        else:
+            assert audio.duration == int(self.duration.total_seconds())
+            assert isinstance(audio.duration, int)
+
+    def test_time_period_int_deprecated(self, recwarn, PTB_TIMEDELTA, audio):
+        audio.duration
+
+        if PTB_TIMEDELTA:
+            assert len(recwarn) == 0
+        else:
+            assert len(recwarn) == 1
+            assert "`duration` will be of type `datetime.timedelta`" in str(recwarn[0].message)
+            assert recwarn[0].category is PTBDeprecationWarning
+
     def test_equality(self, audio):
         a = Audio(audio.file_id, audio.file_unique_id, audio.duration)
         b = Audio("", audio.file_unique_id, audio.duration)
@@ -150,7 +171,9 @@ class TestAudioWithoutRequest(AudioTestBase):
         assert await offline_bot.send_audio(chat_id, audio_file, filename="custom_filename")
 
     @pytest.mark.parametrize("local_mode", [True, False])
-    async def test_send_audio_local_files(self, monkeypatch, offline_bot, chat_id, local_mode):
+    async def test_send_audio_local_files(
+        self, dummy_message_dict, monkeypatch, offline_bot, chat_id, local_mode
+    ):
         try:
             offline_bot._local_mode = local_mode
             # For just test that the correct paths are passed as we have no local Bot API set up
@@ -166,6 +189,7 @@ class TestAudioWithoutRequest(AudioTestBase):
                     test_flag = isinstance(data.get("audio"), InputFile) and isinstance(
                         data.get("thumbnail"), InputFile
                     )
+                return dummy_message_dict
 
             monkeypatch.setattr(offline_bot, "_post", make_assertion)
             await offline_bot.send_audio(chat_id, file, thumbnail=file)
@@ -211,12 +235,13 @@ class TestAudioWithoutRequest(AudioTestBase):
 
 
 class TestAudioWithRequest(AudioTestBase):
-    async def test_send_all_args(self, bot, chat_id, audio_file, thumb_file):
+    @pytest.mark.parametrize("duration", [3, dtm.timedelta(seconds=3)])
+    async def test_send_all_args(self, bot, chat_id, audio_file, thumb_file, duration):
         message = await bot.send_audio(
             chat_id,
             audio=audio_file,
             caption=self.caption,
-            duration=self.duration,
+            duration=duration,
             performer=self.performer,
             title=self.title,
             disable_notification=False,
@@ -232,7 +257,7 @@ class TestAudioWithRequest(AudioTestBase):
         assert isinstance(message.audio.file_unique_id, str)
         assert message.audio.file_unique_id is not None
         assert message.audio.file_id is not None
-        assert message.audio.duration == self.duration
+        assert message.audio._duration == self.duration
         assert message.audio.performer == self.performer
         assert message.audio.title == self.title
         assert message.audio.file_name == self.file_name
