@@ -169,7 +169,9 @@ class TestDocumentWithoutRequest(DocumentTestBase):
         )
 
     @pytest.mark.parametrize("local_mode", [True, False])
-    async def test_send_document_local_files(self, monkeypatch, offline_bot, chat_id, local_mode):
+    async def test_send_document_local_files(
+        self, dummy_message_dict, monkeypatch, offline_bot, chat_id, local_mode
+    ):
         try:
             offline_bot._local_mode = local_mode
             # For just test that the correct paths are passed as we have no local Bot API set up
@@ -187,6 +189,7 @@ class TestDocumentWithoutRequest(DocumentTestBase):
                     test_flag = isinstance(data.get("document"), InputFile) and isinstance(
                         data.get("thumbnail"), InputFile
                     )
+                return dummy_message_dict
 
             monkeypatch.setattr(offline_bot, "_post", make_assertion)
             await offline_bot.send_document(chat_id, file, thumbnail=file)
