@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2024
+# Copyright (C) 2015-2025
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -21,7 +21,6 @@ import pytest
 
 from telegram import InputSticker, MaskPosition
 from telegram._files.inputfile import InputFile
-from tests._files.test_sticker import video_sticker_file  # noqa: F401
 from tests.auxil.files import data_file
 from tests.auxil.slots import mro_slots
 
@@ -29,15 +28,15 @@ from tests.auxil.slots import mro_slots
 @pytest.fixture(scope="module")
 def input_sticker():
     return InputSticker(
-        sticker=TestInputStickerBase.sticker,
-        emoji_list=TestInputStickerBase.emoji_list,
-        mask_position=TestInputStickerBase.mask_position,
-        keywords=TestInputStickerBase.keywords,
-        format=TestInputStickerBase.format,
+        sticker=InputStickerTestBase.sticker,
+        emoji_list=InputStickerTestBase.emoji_list,
+        mask_position=InputStickerTestBase.mask_position,
+        keywords=InputStickerTestBase.keywords,
+        format=InputStickerTestBase.format,
     )
 
 
-class TestInputStickerBase:
+class InputStickerTestBase:
     sticker = "fake_file_id"
     emoji_list = ("👍", "👎")
     mask_position = MaskPosition("forehead", 0.5, 0.5, 0.5)
@@ -45,7 +44,7 @@ class TestInputStickerBase:
     format = "static"
 
 
-class TestInputStickerWithoutRequest(TestInputStickerBase):
+class TestInputStickerWithoutRequest(InputStickerTestBase):
     def test_slot_behaviour(self, input_sticker):
         inst = input_sticker
         for attr in inst.__slots__:
@@ -77,7 +76,7 @@ class TestInputStickerWithoutRequest(TestInputStickerBase):
         assert input_sticker_dict["keywords"] == list(input_sticker.keywords)
         assert input_sticker_dict["format"] == input_sticker.format
 
-    def test_with_sticker_input_types(self, video_sticker_file):  # noqa: F811
+    def test_with_sticker_input_types(self, video_sticker_file):
         sticker = InputSticker(sticker=video_sticker_file, emoji_list=["👍"], format="video")
         assert isinstance(sticker.sticker, InputFile)
         sticker = InputSticker(data_file("telegram_video_sticker.webm"), ["👍"], "video")
