@@ -17,6 +17,7 @@
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 import asyncio
+import datetime as dtm
 
 import pytest
 
@@ -24,6 +25,7 @@ from telegram import Location, ReplyParameters
 from telegram.constants import ParseMode
 from telegram.error import BadRequest
 from telegram.request import RequestData
+from telegram.warnings import PTBDeprecationWarning
 from tests.auxil.build_messages import make_message
 from tests.auxil.slots import mro_slots
 
@@ -44,7 +46,7 @@ class LocationTestBase:
     latitude = -23.691288
     longitude = -46.788279
     horizontal_accuracy = 999
-    live_period = 60
+    live_period = dtm.timedelta(seconds=60)
     heading = 90
     proximity_alert_radius = 50
 
@@ -60,7 +62,7 @@ class TestLocationWithoutRequest(LocationTestBase):
             "latitude": self.latitude,
             "longitude": self.longitude,
             "horizontal_accuracy": self.horizontal_accuracy,
-            "live_period": self.live_period,
+            "live_period": int(self.live_period.total_seconds()),
             "heading": self.heading,
             "proximity_alert_radius": self.proximity_alert_radius,
         }
@@ -70,7 +72,7 @@ class TestLocationWithoutRequest(LocationTestBase):
         assert location.latitude == self.latitude
         assert location.longitude == self.longitude
         assert location.horizontal_accuracy == self.horizontal_accuracy
-        assert location.live_period == self.live_period
+        assert location._live_period == self.live_period
         assert location.heading == self.heading
         assert location.proximity_alert_radius == self.proximity_alert_radius
 
@@ -80,10 +82,29 @@ class TestLocationWithoutRequest(LocationTestBase):
         assert location_dict["latitude"] == location.latitude
         assert location_dict["longitude"] == location.longitude
         assert location_dict["horizontal_accuracy"] == location.horizontal_accuracy
-        assert location_dict["live_period"] == location.live_period
+        assert location_dict["live_period"] == int(self.live_period.total_seconds())
+        assert isinstance(location_dict["live_period"], int)
         assert location["heading"] == location.heading
         assert location["proximity_alert_radius"] == location.proximity_alert_radius
 
+    def test_time_period_properties(self, PTB_TIMEDELTA, location):
+        if PTB_TIMEDELTA:
+            assert location.live_period == self.live_period
+            assert isinstance(location.live_period, dtm.timedelta)
+        else:
+            assert location.live_period == int(self.live_period.total_seconds())
+            assert isinstance(location.live_period, int)
+
+    def test_time_period_int_deprecated(self, recwarn, PTB_TIMEDELTA, location):
+        location.live_period
+
+        if PTB_TIMEDELTA:
+            assert len(recwarn) == 0
+        else:
+            assert len(recwarn) == 1
+            assert "`live_period` will be of type `datetime.timedelta`" in str(recwarn[0].message)
+            assert recwarn[0].category is PTBDeprecationWarning
+
     def test_equality(self):
         a = Location(self.longitude, self.latitude)
         b = Location(self.longitude, self.latitude)
@@ -238,12 +259,16 @@ class TestLocationWithRequest:
         assert not unprotected.has_protected_content
 
     @pytest.mark.xfail
-    async def test_send_live_location(self, bot, chat_id):
+    @pytest.mark.parametrize(
+        ("live_period", "edit_live_period"),
+        [(80, 200), (dtm.timedelta(seconds=80), dtm.timedelta(seconds=200))],
+    )
+    async def test_send_live_location(self, bot, chat_id, live_period, edit_live_period):
         message = await bot.send_location(
             chat_id=chat_id,
             latitude=52.223880,
             longitude=5.166146,
-            live_period=80,
+            live_period=live_period,
             horizontal_accuracy=50,
             heading=90,
             proximity_alert_radius=1000,
@@ -266,7 +291,7 @@ class TestLocationWithRequest:
             horizontal_accuracy=30,
             heading=10,
             proximity_alert_radius=500,
-            live_period=200,
+            live_period=edit_live_period,
         )
 
         assert pytest.approx(message2.location.latitude, rel=1e-5) == 52.223098
@@ -276,7 +301,7 @@ class TestLocationWithRequest:
         assert message2.location.proximity_alert_radius == 500
         assert message2.location.live_period == 200
 
-        await bot.stop_message_live_location(message.chat_id, message.message_id)
+        assert await bot.stop_message_live_location(message.chat_id, message.message_id)
         with pytest.raises(BadRequest, match="Message can't be edited"):
             await bot.edit_message_live_location(
                 message.chat_id, message.message_id, latitude=52.223880, longitude=5.164306
