@@ -144,7 +144,9 @@ class TestPhotoWithoutRequest(PhotoTestBase):
         assert await offline_bot.send_photo(chat_id, photo_file, filename="custom_filename")
 
     @pytest.mark.parametrize("local_mode", [True, False])
-    async def test_send_photo_local_files(self, monkeypatch, offline_bot, chat_id, local_mode):
+    async def test_send_photo_local_files(
+        self, dummy_message_dict, monkeypatch, offline_bot, chat_id, local_mode
+    ):
         try:
             offline_bot._local_mode = local_mode
             # For just test that the correct paths are passed as we have no local Bot API set up
@@ -158,6 +160,7 @@ class TestPhotoWithoutRequest(PhotoTestBase):
                     test_flag = data.get("photo") == expected
                 else:
                     test_flag = isinstance(data.get("photo"), InputFile)
+                return dummy_message_dict
 
             monkeypatch.setattr(offline_bot, "_post", make_assertion)
             await offline_bot.send_photo(chat_id, file)
