@@ -256,7 +256,9 @@ class TestStickerWithoutRequest(StickerTestBase):
         assert await offline_bot.send_sticker(sticker=sticker, chat_id=chat_id)
 
     @pytest.mark.parametrize("local_mode", [True, False])
-    async def test_send_sticker_local_files(self, monkeypatch, offline_bot, chat_id, local_mode):
+    async def test_send_sticker_local_files(
+        self, dummy_message_dict, monkeypatch, offline_bot, chat_id, local_mode
+    ):
         try:
             offline_bot._local_mode = local_mode
             # For just test that the correct paths are passed as we have no local Bot API set up
@@ -270,6 +272,7 @@ class TestStickerWithoutRequest(StickerTestBase):
                     test_flag = data.get("sticker") == expected
                 else:
                     test_flag = isinstance(data.get("sticker"), InputFile)
+                return dummy_message_dict
 
             monkeypatch.setattr(offline_bot, "_post", make_assertion)
             await offline_bot.send_sticker(chat_id, file)
@@ -581,6 +584,7 @@ class TestStickerSetWithoutRequest(StickerSetTestBase):
                     if local_mode
                     else isinstance(data.get("sticker"), InputFile)
                 )
+                return File(file_id="file_id", file_unique_id="file_unique_id").to_dict()
 
             monkeypatch.setattr(offline_bot, "_post", make_assertion)
             await offline_bot.upload_sticker_file(
