@@ -17,6 +17,7 @@
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 import asyncio
+import datetime as dtm
 import os
 from pathlib import Path
 
@@ -27,6 +28,7 @@ from telegram.constants import ParseMode
 from telegram.error import BadRequest, TelegramError
 from telegram.helpers import escape_markdown
 from telegram.request import RequestData
+from telegram.warnings import PTBDeprecationWarning
 from tests.auxil.bot_method_checks import (
     check_defaults_handling,
     check_shortcut_call,
@@ -37,14 +39,27 @@ from tests.auxil.files import data_file
 from tests.auxil.slots import mro_slots
 
 
+# Override `video` fixture to provide start_timestamp
+@pytest.fixture(scope="module")
+async def video(bot, chat_id):
+    with data_file("telegram.mp4").open("rb") as f:
+        return (
+            await bot.send_video(
+                chat_id, video=f, start_timestamp=VideoTestBase.start_timestamp, read_timeout=50
+            )
+        ).video
+
+
 class VideoTestBase:
     width = 360
     height = 640
-    duration = 5
+    duration = dtm.timedelta(seconds=5)
     file_size = 326534
     mime_type = "video/mp4"
     supports_streaming = True
     file_name = "telegram.mp4"
+    start_timestamp = dtm.timedelta(seconds=3)
+    cover = (PhotoSize("file_id", "unique_id", 640, 360, file_size=0),)
     thumb_width = 180
     thumb_height = 320
     thumb_file_size = 1767
@@ -77,9 +92,10 @@ class TestVideoWithoutRequest(VideoTestBase):
     def test_expected_values(self, video):
         assert video.width == self.width
         assert video.height == self.height
-        assert video.duration == self.duration
+        assert video._duration == self.duration
         assert video.file_size == self.file_size
         assert video.mime_type == self.mime_type
+        assert video._start_timestamp == self.start_timestamp
 
     def test_de_json(self, offline_bot):
         json_dict = {
@@ -87,10 +103,12 @@ class TestVideoWithoutRequest(VideoTestBase):
             "file_unique_id": self.video_file_unique_id,
             "width": self.width,
             "height": self.height,
-            "duration": self.duration,
+            "duration": int(self.duration.total_seconds()),
             "mime_type": self.mime_type,
             "file_size": self.file_size,
             "file_name": self.file_name,
+            "start_timestamp": int(self.start_timestamp.total_seconds()),
+            "cover": [photo_size.to_dict() for photo_size in self.cover],
         }
         json_video = Video.de_json(json_dict, offline_bot)
         assert json_video.api_kwargs == {}
@@ -99,10 +117,12 @@ class TestVideoWithoutRequest(VideoTestBase):
         assert json_video.file_unique_id == self.video_file_unique_id
         assert json_video.width == self.width
         assert json_video.height == self.height
-        assert json_video.duration == self.duration
+        assert json_video._duration == self.duration
         assert json_video.mime_type == self.mime_type
         assert json_video.file_size == self.file_size
         assert json_video.file_name == self.file_name
+        assert json_video._start_timestamp == self.start_timestamp
+        assert json_video.cover == self.cover
 
     def test_to_dict(self, video):
         video_dict = video.to_dict()
@@ -112,10 +132,39 @@ class TestVideoWithoutRequest(VideoTestBase):
         assert video_dict["file_unique_id"] == video.file_unique_id
         assert video_dict["width"] == video.width
         assert video_dict["height"] == video.height
-        assert video_dict["duration"] == video.duration
+        assert video_dict["duration"] == int(self.duration.total_seconds())
+        assert isinstance(video_dict["duration"], int)
         assert video_dict["mime_type"] == video.mime_type
         assert video_dict["file_size"] == video.file_size
         assert video_dict["file_name"] == video.file_name
+        assert video_dict["start_timestamp"] == int(self.start_timestamp.total_seconds())
+        assert isinstance(video_dict["start_timestamp"], int)
+
+    def test_time_period_properties(self, PTB_TIMEDELTA, video):
+        if PTB_TIMEDELTA:
+            assert video.duration == self.duration
+            assert isinstance(video.duration, dtm.timedelta)
+
+            assert video.start_timestamp == self.start_timestamp
+            assert isinstance(video.start_timestamp, dtm.timedelta)
+        else:
+            assert video.duration == int(self.duration.total_seconds())
+            assert isinstance(video.duration, int)
+
+            assert video.start_timestamp == int(self.start_timestamp.total_seconds())
+            assert isinstance(video.start_timestamp, int)
+
+    def test_time_period_int_deprecated(self, recwarn, PTB_TIMEDELTA, video):
+        video.duration
+        video.start_timestamp
+
+        if PTB_TIMEDELTA:
+            assert len(recwarn) == 0
+        else:
+            assert len(recwarn) == 2
+            for i, attr in enumerate(["duration", "start_timestamp"]):
+                assert f"`{attr}` will be of type `datetime.timedelta`" in str(recwarn[i].message)
+                assert recwarn[i].category is PTBDeprecationWarning
 
     def test_equality(self, video):
         a = Video(video.file_id, video.file_unique_id, self.width, self.height, self.duration)
@@ -157,7 +206,9 @@ class TestVideoWithoutRequest(VideoTestBase):
         assert await offline_bot.send_video(chat_id, video_file, filename="custom_filename")
 
     @pytest.mark.parametrize("local_mode", [True, False])
-    async def test_send_video_local_files(self, monkeypatch, offline_bot, chat_id, local_mode):
+    async def test_send_video_local_files(
+        self, dummy_message_dict, monkeypatch, offline_bot, chat_id, local_mode
+    ):
         try:
             offline_bot._local_mode = local_mode
             # For just test that the correct paths are passed as we have no local Bot API set up
@@ -173,6 +224,7 @@ class TestVideoWithoutRequest(VideoTestBase):
                     test_flag = isinstance(data.get("video"), InputFile) and isinstance(
                         data.get("thumbnail"), InputFile
                     )
+                return dummy_message_dict
 
             monkeypatch.setattr(offline_bot, "_post", make_assertion)
             await offline_bot.send_video(chat_id, file, thumbnail=file)
@@ -218,11 +270,14 @@ class TestVideoWithoutRequest(VideoTestBase):
 
 
 class TestVideoWithRequest(VideoTestBase):
-    async def test_send_all_args(self, bot, chat_id, video_file, video, thumb_file):
+    @pytest.mark.parametrize("duration", [dtm.timedelta(seconds=5), 5])
+    async def test_send_all_args(
+        self, bot, chat_id, video_file, video, thumb_file, photo_file, duration
+    ):
         message = await bot.send_video(
             chat_id,
             video_file,
-            duration=self.duration,
+            duration=duration,
             caption=self.caption,
             supports_streaming=self.supports_streaming,
             disable_notification=False,
@@ -231,6 +286,8 @@ class TestVideoWithRequest(VideoTestBase):
             height=video.height,
             parse_mode="Markdown",
             thumbnail=thumb_file,
+            cover=photo_file,
+            start_timestamp=self.start_timestamp,
             has_spoiler=True,
             show_caption_above_media=True,
         )
@@ -251,6 +308,11 @@ class TestVideoWithRequest(VideoTestBase):
         assert message.video.thumbnail.width == self.thumb_width
         assert message.video.thumbnail.height == self.thumb_height
 
+        assert message.video._start_timestamp == self.start_timestamp
+
+        assert isinstance(message.video.cover, tuple)
+        assert isinstance(message.video.cover[0], PhotoSize)
+
         assert message.video.file_name == self.file_name
         assert message.has_protected_content
         assert message.has_media_spoiler
