@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2024
+# Copyright (C) 2015-2025
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -30,20 +30,20 @@ from tests.auxil.slots import mro_slots
 @pytest.fixture(scope="module")
 def inline_query_result_game():
     return InlineQueryResultGame(
-        TestInlineQueryResultGameBase.id_,
-        TestInlineQueryResultGameBase.game_short_name,
-        reply_markup=TestInlineQueryResultGameBase.reply_markup,
+        InlineQueryResultGameTestBase.id_,
+        InlineQueryResultGameTestBase.game_short_name,
+        reply_markup=InlineQueryResultGameTestBase.reply_markup,
     )
 
 
-class TestInlineQueryResultGameBase:
+class InlineQueryResultGameTestBase:
     id_ = "id"
     type_ = "game"
     game_short_name = "game short name"
     reply_markup = InlineKeyboardMarkup([[InlineKeyboardButton("reply_markup")]])
 
 
-class TestInlineQueryResultGameWithoutRequest(TestInlineQueryResultGameBase):
+class TestInlineQueryResultGameWithoutRequest(InlineQueryResultGameTestBase):
     def test_slot_behaviour(self, inline_query_result_game):
         inst = inline_query_result_game
         for attr in inst.__slots__:
