@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2024
+# Copyright (C) 2015-2025
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -26,19 +26,19 @@ from tests.auxil.slots import mro_slots
 @pytest.fixture(scope="module")
 def encrypted_credentials():
     return EncryptedCredentials(
-        TestEncryptedCredentialsBase.data,
-        TestEncryptedCredentialsBase.hash,
-        TestEncryptedCredentialsBase.secret,
+        EncryptedCredentialsTestBase.data,
+        EncryptedCredentialsTestBase.hash,
+        EncryptedCredentialsTestBase.secret,
     )
 
 
-class TestEncryptedCredentialsBase:
+class EncryptedCredentialsTestBase:
     data = "data"
     hash = "hash"
     secret = "secret"
 
 
-class TestEncryptedCredentialsWithoutRequest(TestEncryptedCredentialsBase):
+class TestEncryptedCredentialsWithoutRequest(EncryptedCredentialsTestBase):
     def test_slot_behaviour(self, encrypted_credentials):
         inst = encrypted_credentials
         for attr in inst.__slots__:
