@@ -22,12 +22,14 @@ import pytest
 
 from telegram import (
     AffiliateInfo,
+    Chat,
     Gift,
     PaidMediaVideo,
     RevenueWithdrawalStatePending,
     Sticker,
     TransactionPartner,
     TransactionPartnerAffiliateProgram,
+    TransactionPartnerChat,
     TransactionPartnerFragment,
     TransactionPartnerOther,
     TransactionPartnerTelegramAds,
@@ -61,6 +63,7 @@ class TransactionPartnerTestBase:
         first_name="user",
         last_name="user",
     )
+    transaction_type = "premium_purchase"
     invoice_payload = "invoice_payload"
     paid_media = (
         PaidMediaVideo(
@@ -95,6 +98,11 @@ class TransactionPartnerTestBase:
         amount=42,
     )
     request_count = 42
+    chat = Chat(
+        id=3,
+        type=Chat.CHANNEL,
+    )
+    premium_subscription_duration = 3
 
 
 class TestTransactionPartnerWithoutRequest(TransactionPartnerTestBase):
@@ -114,9 +122,6 @@ class TestTransactionPartnerWithoutRequest(TransactionPartnerTestBase):
         assert transaction_partner.api_kwargs == {}
         assert transaction_partner.type == "unknown"
 
-        assert TransactionPartner.de_json(None, offline_bot) is None
-        assert TransactionPartner.de_json({}, offline_bot) is None
-
     @pytest.mark.parametrize(
         ("tp_type", "subclass"),
         [
@@ -126,6 +131,7 @@ class TestTransactionPartnerWithoutRequest(TransactionPartnerTestBase):
             ("telegram_ads", TransactionPartnerTelegramAds),
             ("telegram_api", TransactionPartnerTelegramApi),
             ("other", TransactionPartnerOther),
+            ("chat", TransactionPartnerChat),
         ],
     )
     def test_subclass(self, offline_bot, tp_type, subclass):
@@ -133,6 +139,7 @@ class TestTransactionPartnerWithoutRequest(TransactionPartnerTestBase):
             "type": tp_type,
             "commission_per_mille": self.commission_per_mille,
             "user": self.user.to_dict(),
+            "transaction_type": self.transaction_type,
             "request_count": self.request_count,
         }
         tp = TransactionPartner.de_json(json_dict, offline_bot)
@@ -191,9 +198,6 @@ class TestTransactionPartnerAffiliateProgramWithoutRequest(TransactionPartnerTes
         assert tp.commission_per_mille == self.commission_per_mille
         assert tp.sponsor_user == self.sponsor_user
 
-        assert TransactionPartnerAffiliateProgram.de_json(None, offline_bot) is None
-        assert TransactionPartnerAffiliateProgram.de_json({}, offline_bot) is None
-
     def test_to_dict(self, transaction_partner_affiliate_program):
         json_dict = transaction_partner_affiliate_program.to_dict()
         assert json_dict["type"] == self.type
@@ -243,8 +247,6 @@ class TestTransactionPartnerFragmentWithoutRequest(TransactionPartnerTestBase):
         assert tp.type == "fragment"
         assert tp.withdrawal_state == self.withdrawal_state
 
-        assert TransactionPartnerFragment.de_json(None, offline_bot) is None
-
     def test_to_dict(self, transaction_partner_fragment):
         json_dict = transaction_partner_fragment.to_dict()
         assert json_dict["type"] == self.type
@@ -269,11 +271,13 @@ class TestTransactionPartnerFragmentWithoutRequest(TransactionPartnerTestBase):
 @pytest.fixture
 def transaction_partner_user():
     return TransactionPartnerUser(
+        transaction_type=TransactionPartnerTestBase.transaction_type,
         user=TransactionPartnerTestBase.user,
         invoice_payload=TransactionPartnerTestBase.invoice_payload,
         paid_media=TransactionPartnerTestBase.paid_media,
         paid_media_payload=TransactionPartnerTestBase.paid_media_payload,
         subscription_period=TransactionPartnerTestBase.subscription_period,
+        premium_subscription_duration=TransactionPartnerTestBase.premium_subscription_duration,
     )
 
 
@@ -289,38 +293,43 @@ class TestTransactionPartnerUserWithoutRequest(TransactionPartnerTestBase):
     def test_de_json(self, offline_bot):
         json_dict = {
             "user": self.user.to_dict(),
+            "transaction_type": self.transaction_type,
             "invoice_payload": self.invoice_payload,
             "paid_media": [pm.to_dict() for pm in self.paid_media],
             "paid_media_payload": self.paid_media_payload,
             "subscription_period": self.subscription_period.total_seconds(),
+            "premium_subscription_duration": self.premium_subscription_duration,
         }
         tp = TransactionPartnerUser.de_json(json_dict, offline_bot)
         assert tp.api_kwargs == {}
         assert tp.type == "user"
         assert tp.user == self.user
+        assert tp.transaction_type == self.transaction_type
         assert tp.invoice_payload == self.invoice_payload
         assert tp.paid_media == self.paid_media
         assert tp.paid_media_payload == self.paid_media_payload
         assert tp.subscription_period == self.subscription_period
-
-        assert TransactionPartnerUser.de_json(None, offline_bot) is None
-        assert TransactionPartnerUser.de_json({}, offline_bot) is None
+        assert tp.premium_subscription_duration == self.premium_subscription_duration
 
     def test_to_dict(self, transaction_partner_user):
         json_dict = transaction_partner_user.to_dict()
         assert json_dict["type"] == self.type
+        assert json_dict["transaction_type"] == self.transaction_type
         assert json_dict["user"] == self.user.to_dict()
         assert json_dict["invoice_payload"] == self.invoice_payload
         assert json_dict["paid_media"] == [pm.to_dict() for pm in self.paid_media]
         assert json_dict["paid_media_payload"] == self.paid_media_payload
         assert json_dict["subscription_period"] == self.subscription_period.total_seconds()
+        assert json_dict["premium_subscription_duration"] == self.premium_subscription_duration
 
     def test_equality(self, transaction_partner_user):
         a = transaction_partner_user
         b = TransactionPartnerUser(
+            transaction_type=self.transaction_type,
             user=self.user,
         )
         c = TransactionPartnerUser(
+            transaction_type=self.transaction_type,
             user=User(id=1, is_bot=False, first_name="user", last_name="user"),
         )
         d = User(id=1, is_bot=False, first_name="user", last_name="user")
@@ -355,8 +364,6 @@ class TestTransactionPartnerOtherWithoutRequest(TransactionPartnerTestBase):
         assert tp.api_kwargs == {}
         assert tp.type == "other"
 
-        assert TransactionPartnerOther.de_json(None, offline_bot) is None
-
     def test_to_dict(self, transaction_partner_other):
         json_dict = transaction_partner_other.to_dict()
         assert json_dict == {"type": self.type}
@@ -397,8 +404,6 @@ class TestTransactionPartnerTelegramAdsWithoutRequest(TransactionPartnerTestBase
         assert tp.api_kwargs == {}
         assert tp.type == "telegram_ads"
 
-        assert TransactionPartnerTelegramAds.de_json(None, offline_bot) is None
-
     def test_to_dict(self, transaction_partner_telegram_ads):
         json_dict = transaction_partner_telegram_ads.to_dict()
         assert json_dict == {"type": self.type}
@@ -442,8 +447,6 @@ class TestTransactionPartnerTelegramApiWithoutRequest(TransactionPartnerTestBase
         assert tp.type == "telegram_api"
         assert tp.request_count == self.request_count
 
-        assert TransactionPartnerTelegramApi.de_json(None, offline_bot) is None
-
     def test_to_dict(self, transaction_partner_telegram_api):
         json_dict = transaction_partner_telegram_api.to_dict()
         assert json_dict["type"] == self.type
@@ -467,3 +470,58 @@ class TestTransactionPartnerTelegramApiWithoutRequest(TransactionPartnerTestBase
 
         assert a != d
         assert hash(a) != hash(d)
+
+
+@pytest.fixture
+def transaction_partner_chat():
+    return TransactionPartnerChat(
+        chat=TransactionPartnerTestBase.chat,
+        gift=TransactionPartnerTestBase.gift,
+    )
+
+
+class TestTransactionPartnerChatWithoutRequest(TransactionPartnerTestBase):
+    type = TransactionPartnerType.CHAT
+
+    def test_slot_behaviour(self, transaction_partner_chat):
+        inst = transaction_partner_chat
+        for attr in inst.__slots__:
+            assert getattr(inst, attr, "err") != "err", f"got extra slot '{attr}'"
+        assert len(mro_slots(inst)) == len(set(mro_slots(inst))), "duplicate slot"
+
+    def test_de_json(self, offline_bot):
+        json_dict = {
+            "chat": self.chat.to_dict(),
+            "gift": self.gift.to_dict(),
+        }
+        tp = TransactionPartnerChat.de_json(json_dict, offline_bot)
+        assert tp.api_kwargs == {}
+        assert tp.type == "chat"
+        assert tp.chat == self.chat
+        assert tp.gift == self.gift
+
+    def test_to_dict(self, transaction_partner_chat):
+        json_dict = transaction_partner_chat.to_dict()
+        assert json_dict["type"] == self.type
+        assert json_dict["chat"] == self.chat.to_dict()
+        assert json_dict["gift"] == self.gift.to_dict()
+
+    def test_equality(self, transaction_partner_chat):
+        a = transaction_partner_chat
+        b = TransactionPartnerChat(
+            chat=self.chat,
+            gift=self.gift,
+        )
+        c = TransactionPartnerChat(
+            chat=Chat(id=1, type=Chat.CHANNEL),
+        )
+        d = Chat(id=1, type=Chat.CHANNEL)
+
+        assert a == b
+        assert hash(a) == hash(b)
+
+        assert a != c
+        assert hash(a) != hash(c)
+
+        assert a != d
+        assert hash(a) != hash(d)
