@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2024
+# Copyright (C) 2015-2025
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -31,44 +31,44 @@ from tests.auxil.slots import mro_slots
 @pytest.fixture(scope="module")
 def shipping_query(bot):
     sq = ShippingQuery(
-        TestShippingQueryBase.id_,
-        TestShippingQueryBase.from_user,
-        TestShippingQueryBase.invoice_payload,
-        TestShippingQueryBase.shipping_address,
+        ShippingQueryTestBase.id_,
+        ShippingQueryTestBase.from_user,
+        ShippingQueryTestBase.invoice_payload,
+        ShippingQueryTestBase.shipping_address,
     )
     sq.set_bot(bot)
     return sq
 
 
-class TestShippingQueryBase:
+class ShippingQueryTestBase:
     id_ = "5"
     invoice_payload = "invoice_payload"
     from_user = User(0, "", False)
     shipping_address = ShippingAddress("GB", "", "London", "12 Grimmauld Place", "", "WC1")
 
 
-class TestShippingQueryWithoutRequest(TestShippingQueryBase):
+class TestShippingQueryWithoutRequest(ShippingQueryTestBase):
     def test_slot_behaviour(self, shipping_query):
         inst = shipping_query
         for attr in inst.__slots__:
             assert getattr(inst, attr, "err") != "err", f"got extra slot '{attr}'"
         assert len(mro_slots(inst)) == len(set(mro_slots(inst))), "duplicate slot"
 
-    def test_de_json(self, bot):
+    def test_de_json(self, offline_bot):
         json_dict = {
             "id": self.id_,
             "invoice_payload": self.invoice_payload,
             "from": self.from_user.to_dict(),
             "shipping_address": self.shipping_address.to_dict(),
         }
-        shipping_query = ShippingQuery.de_json(json_dict, bot)
+        shipping_query = ShippingQuery.de_json(json_dict, offline_bot)
         assert shipping_query.api_kwargs == {}
 
         assert shipping_query.id == self.id_
         assert shipping_query.invoice_payload == self.invoice_payload
         assert shipping_query.from_user == self.from_user
         assert shipping_query.shipping_address == self.shipping_address
-        assert shipping_query.get_bot() is bot
+        assert shipping_query.get_bot() is offline_bot
 
     def test_to_dict(self, shipping_query):
         shipping_query_dict = shipping_query.to_dict()
