@@ -23,6 +23,7 @@ import zoneinfo
 import pytest
 
 from telegram._utils import datetime as tg_dtm
+from telegram._utils.datetime import get_zone_info
 from telegram.ext import Defaults
 
 # sample time specification values categorised into absolute / delta / time-of-day
@@ -138,7 +139,10 @@ class TestDatetime:
         # of an xpass when the test is run in a timezone with the same UTC offset
         ref_datetime = dtm.datetime(1970, 1, 1, 12)
         utc_offset = timezone.utcoffset(ref_datetime)
-        ref_t, time_of_day = tg_dtm._datetime_to_float_timestamp(ref_datetime), ref_datetime.time()
+        ref_t, time_of_day = (
+            tg_dtm._datetime_to_float_timestamp(ref_datetime),
+            ref_datetime.time(),
+        )
         aware_time_of_day = tg_dtm.localize(ref_datetime, timezone).timetz()
 
         # first test that naive time is assumed to be utc:
@@ -168,7 +172,7 @@ class TestDatetime:
             assert tg_dtm.to_timestamp(i) == int(tg_dtm.to_float_timestamp(i)), f"Failed for {i}"
 
     def test_to_timestamp_none(self):
-        # this 'convenience' behaviour has been left left for backwards compatibility
+        # this 'convenience' behaviour has been left for backwards compatibility
         assert tg_dtm.to_timestamp(None) is None
 
     def test_from_timestamp_none(self):
@@ -193,6 +197,21 @@ class TestDatetime:
         assert tg_dtm.extract_tzinfo_from_defaults(bot) is None
         assert tg_dtm.extract_tzinfo_from_defaults(raw_bot) is None
 
+    def test_get_zone_info_with_valid_timezone_string(self):
+        """Test with a valid timezone string."""
+        tz = "Asia/Tokyo"
+        result = get_zone_info(tz)
+        assert isinstance(result, zoneinfo.ZoneInfo)
+        assert str(result) == "Asia/Tokyo"
+
+    def test_get_zone_info_with_invalid_timezone_string(self):
+        """Test with an invalid timezone string."""
+        with pytest.raises(
+            zoneinfo.ZoneInfoNotFoundError,
+            match=r"No time zone found.*Invalid/Timezone.*install the tzdata",
+        ):
+            get_zone_info("Invalid/Timezone")
+
     @pytest.mark.parametrize(
         ("arg", "timedelta_result", "number_result"),
         [
