@@ -17,13 +17,15 @@
 #  You should have received a copy of the GNU Lesser Public License
 #  along with this program.  If not, see [http://www.gnu.org/licenses/].
 """Provides functions to test both methods."""
+
 import datetime as dtm
 import functools
 import inspect
 import re
 import zoneinfo
 from collections.abc import Collection, Iterable
-from typing import Any, Callable, Optional
+from types import GenericAlias
+from typing import Any, Callable, ForwardRef, Optional, Union
 
 import pytest
 
@@ -31,10 +33,10 @@ import telegram  # for ForwardRef resolution
 from telegram import (
     Bot,
     ChatPermissions,
-    File,
     InlineQueryResultArticle,
     InlineQueryResultCachedPhoto,
     InputMediaPhoto,
+    InputPaidMediaPhoto,
     InputTextMessageContent,
     LinkPreviewOptions,
     ReplyParameters,
@@ -46,6 +48,7 @@ from telegram._utils.defaultvalue import DEFAULT_NONE, DefaultValue
 from telegram.constants import InputMediaType
 from telegram.ext import Defaults, ExtBot
 from telegram.request import RequestData
+from tests.auxil.dummy_objects import get_dummy_object_json_dict
 
 FORWARD_REF_PATTERN = re.compile(r"ForwardRef\('(?P<class_name>\w+)'\)")
 """ A pattern to find a class name in a ForwardRef typing annotation.
@@ -68,7 +71,7 @@ def check_shortcut_signature(
         bot_method: The bot method, e.g. :meth:`telegram.Bot.send_message`
         shortcut_kwargs: The kwargs passed by the shortcut directly, e.g. ``chat_id``
         additional_kwargs: Additional kwargs of the shortcut that the bot method doesn't have, e.g.
-            ``quote``.
+            ``do_quote``.
         annotation_overrides: A dictionary of exceptions for the annotation comparison. The key is
             the name of the argument, the value is a tuple of the expected annotation and
             the default value. E.g. ``{'parse_mode': (str, 'None')}``.
@@ -226,21 +229,18 @@ async def check_shortcut_call(
 
     shortcut_signature = inspect.signature(shortcut_method)
     # auto_pagination: Special casing for InlineQuery.answer
-    # quote: Don't test deprecated "quote" parameter of Message.reply_*
     kwargs = {
-        name: name
-        for name in shortcut_signature.parameters
-        if name not in ["auto_pagination", "quote"]
+        name: name for name in shortcut_signature.parameters if name not in ["auto_pagination"]
     }
     if "reply_parameters" in kwargs:
         kwargs["reply_parameters"] = ReplyParameters(message_id=1)
 
     # We tested this for a long time, but Bot API 7.0 deprecated it in favor of
-    # reply_parameters. In the transition phase, both exist in a mutually exclusive
-    # way. Testing both cases would require a lot of additional code, so we just
-    # ignore this parameter here until it is removed.
-    kwargs.pop("reply_to_message_id", None)
-    expected_args.discard("reply_to_message_id")
+    # reply_parameters. Testing both cases would require a lot of additional code, so we just
+    # ignore these parameters here.
+    for arg in ["reply_to_message_id", "allow_sending_without_reply"]:
+        kwargs.pop(arg, None)
+        expected_args.discard(arg)
 
     async def make_assertion(**kw):
         # name == value makes sure that
@@ -252,16 +252,12 @@ async def check_shortcut_call(
             if name in ignored_args
             or (value == name or (name == "reply_parameters" and value.message_id == 1))
         }
-        if not received_kwargs == expected_args:
+        if received_kwargs != expected_args:
             raise Exception(
                 f"{orig_bot_method.__name__} did not receive correct value for the parameters "
                 f"{expected_args - received_kwargs}"
             )
 
-        if bot_method_name == "get_file":
-            # This is here mainly for PassportFile.get_file, which calls .set_credentials on the
-            # return value
-            return File(file_id="result", file_unique_id="result")
         return True
 
     setattr(bot, bot_method_name, make_assertion)
@@ -288,8 +284,13 @@ def build_kwargs(
             elif name in ["prices", "commands", "errors"]:
                 kws[name] = []
             elif name == "media":
-                media = InputMediaPhoto("media", parse_mode=manually_passed_value)
-                if "list" in str(param.annotation).lower():
+                if "star_count" in signature.parameters:
+                    media = InputPaidMediaPhoto("media")
+                else:
+                    media = InputMediaPhoto("media", parse_mode=manually_passed_value)
+
+                param_annotation = str(param.annotation).lower()
+                if "sequence" in param_annotation or "list" in param_annotation:
                     kws[name] = [media]
                 else:
                     kws[name] = media
@@ -392,6 +393,33 @@ def make_assertion_for_link_preview_options(
             )
 
 
+def _check_forward_ref(obj: object) -> Union[str, object]:
+    if isinstance(obj, ForwardRef):
+        return obj.__forward_arg__
+    return obj
+
+
+def guess_return_type_name(method: Callable[[...], Any]) -> tuple[Union[str, object], bool]:
+    # Using typing.get_type_hints(method) would be the nicer as it also resolves ForwardRefs
+    # and string annotations. But it also wants to resolve the parameter annotations, which
+    # need additional namespaces and that's not worth the struggle for now …
+    return_annotation = _check_forward_ref(inspect.signature(method).return_annotation)
+    as_tuple = False
+
+    if isinstance(return_annotation, GenericAlias):
+        if return_annotation.__origin__ is tuple:
+            as_tuple = True
+        else:
+            raise ValueError(
+                f"Return type of {method.__name__} is a GenericAlias. This can not be handled yet."
+            )
+
+    # For tuples and Unions, we simply take the first element
+    if hasattr(return_annotation, "__args__"):
+        return _check_forward_ref(return_annotation.__args__[0]), as_tuple
+    return return_annotation, as_tuple
+
+
 _EUROPE_BERLIN_TS = to_timestamp(
     dtm.datetime(2000, 1, 1, 0, tzinfo=zoneinfo.ZoneInfo("Europe/Berlin"))
 )
@@ -483,7 +511,8 @@ async def make_assertion(
             )
 
     media = data.pop("media", None)
-    if media:
+    paid_media = media and data.pop("star_count", None)
+    if media and not paid_media:
         if isinstance(media, dict) and isinstance(media.get("type", None), InputMediaType):
             check_input_media(media)
         else:
@@ -547,15 +576,6 @@ async def make_assertion(
             if default_value_expected and date_param != _AMERICA_NEW_YORK_TS:
                 pytest.fail(f"Naive `{key}` should have been interpreted as America/New_York")
 
-    if method_name in ["get_file", "get_small_file", "get_big_file"]:
-        # This is here mainly for PassportFile.get_file, which calls .set_credentials on the
-        # return value
-        out = File(file_id="result", file_unique_id="result")
-        return out.to_dict()
-    # Otherwise return None by default, as TGObject.de_json/list(None) in [None, []]
-    # That way we can check what gets passed to Request.post without having to actually
-    # make a request
-    # Some methods expect specific output, so we allow to customize that
     if isinstance(return_value, TelegramObject):
         return return_value.to_dict()
     return return_value
@@ -564,7 +584,6 @@ async def make_assertion(
 async def check_defaults_handling(
     method: Callable,
     bot: Bot,
-    return_value=None,
     no_default_kwargs: Collection[str] = frozenset(),
 ) -> bool:
     """
@@ -574,9 +593,6 @@ async def check_defaults_handling(
         method: The shortcut/bot_method
         bot: The bot. May be a telegram.Bot or a telegram.ext.ExtBot. In the former case, all
             default values will be converted to None.
-        return_value: Optional. The return value of Bot._post that the method expects. Defaults to
-            None. get_file is automatically handled. If this is a `TelegramObject`, Bot._post will
-            return the `to_dict` representation of it.
         no_default_kwargs: Optional. A collection of keyword arguments that should not have default
             values. Defaults to an empty frozenset.
 
@@ -603,21 +619,17 @@ async def check_defaults_handling(
         kwargs_need_default.remove("parse_mode")
 
     defaults_no_custom_defaults = Defaults()
-    kwargs = {kwarg: "custom_default" for kwarg in inspect.signature(Defaults).parameters}
+    kwargs = dict.fromkeys(inspect.signature(Defaults).parameters, "custom_default")
     kwargs["tzinfo"] = zoneinfo.ZoneInfo("America/New_York")
-    kwargs.pop("disable_web_page_preview")  # mutually exclusive with link_preview_options
-    kwargs.pop("quote")  # mutually exclusive with do_quote
     kwargs["link_preview_options"] = LinkPreviewOptions(
         url="custom_default", show_above_text="custom_default"
     )
     defaults_custom_defaults = Defaults(**kwargs)
 
-    expected_return_values = [None, ()] if return_value is None else [return_value]
-    if method.__name__ in ["get_file", "get_small_file", "get_big_file"]:
-        expected_return_values = [File(file_id="result", file_unique_id="result")]
-
     request = bot._request[0] if get_updates else bot.request
     orig_post = request.post
+    return_value = get_dummy_object_json_dict(*guess_return_type_name(method))
+
     try:
         if raw_bot:
             combinations = [(None, None)]
@@ -641,7 +653,7 @@ async def check_defaults_handling(
                 expected_defaults_value=expected_defaults_value,
             )
             request.post = assertion_callback
-            assert await method(**kwargs) in expected_return_values
+            await method(**kwargs)
 
             # 2: test that we get the manually passed non-None value
             kwargs = build_kwargs(
@@ -656,7 +668,7 @@ async def check_defaults_handling(
                 expected_defaults_value=expected_defaults_value,
             )
             request.post = assertion_callback
-            assert await method(**kwargs) in expected_return_values
+            await method(**kwargs)
 
             # 3: test that we get the manually passed None value
             kwargs = build_kwargs(
@@ -671,7 +683,7 @@ async def check_defaults_handling(
                 expected_defaults_value=expected_defaults_value,
             )
             request.post = assertion_callback
-            assert await method(**kwargs) in expected_return_values
+            await method(**kwargs)
     except Exception as exc:
         raise exc
     finally:
