@@ -20,6 +20,7 @@
 modify behavior of the respective parent classes in order to make them easier to use in the
 pytest framework. A common change is to allow monkeypatching of the class members by not
 enforcing slots in the subclasses."""
+
 from telegram import Bot, Message, User
 from telegram.ext import Application, ExtBot, Updater
 from tests.auxil.ci_bots import BOT_INFO_PROVIDER
@@ -66,7 +67,7 @@ class PytestExtBot(ExtBot):
         self._unfreeze()
 
     # Here we override get_me for caching because we don't want to call the API repeatedly in tests
-    async def get_me(self, *args, **kwargs):
+    async def get_me(self, *args, **kwargs) -> User:
         return await _mocked_get_me(self)
 
 
@@ -77,7 +78,7 @@ class PytestBot(Bot):
         self._unfreeze()
 
     # Here we override get_me for caching because we don't want to call the API repeatedly in tests
-    async def get_me(self, *args, **kwargs):
+    async def get_me(self, *args, **kwargs) -> User:
         return await _mocked_get_me(self)
 
 
