@@ -18,6 +18,7 @@
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 import asyncio
 import logging
+import os
 import sys
 import zoneinfo
 from pathlib import Path
@@ -37,10 +38,15 @@ from telegram import (
     User,
 )
 from telegram.ext import Defaults
-from tests.auxil.build_messages import DATE
+from tests.auxil.build_messages import DATE, make_message
 from tests.auxil.ci_bots import BOT_INFO_PROVIDER, JOB_INDEX
 from tests.auxil.constants import PRIVATE_KEY, TEST_TOPIC_ICON_COLOR, TEST_TOPIC_NAME
-from tests.auxil.envvars import GITHUB_ACTIONS, RUN_TEST_OFFICIAL, TEST_WITH_OPT_DEPS
+from tests.auxil.envvars import (
+    GITHUB_ACTIONS,
+    RUN_TEST_OFFICIAL,
+    TEST_WITH_OPT_DEPS,
+    env_var_2_bool,
+)
 from tests.auxil.files import data_file
 from tests.auxil.networking import NonchalantHttpxRequest
 from tests.auxil.pytest_classes import PytestBot, make_bot
@@ -129,6 +135,18 @@ if GITHUB_ACTIONS and JOB_INDEX == 0:
             )
 
 
+@pytest.fixture(scope="module", params=["true", "1", "false", "gibberish", None])
+def PTB_TIMEDELTA(request):
+    # Here we manually use monkeypatch to give this fixture module scope
+    monkeypatch = pytest.MonkeyPatch()
+    if request.param is not None:
+        monkeypatch.setenv("PTB_TIMEDELTA", request.param)
+    else:
+        monkeypatch.delenv("PTB_TIMEDELTA", raising=False)
+    yield env_var_2_bool(os.getenv("PTB_TIMEDELTA"))
+    monkeypatch.undo()
+
+
 # Redefine the event_loop fixture to have a session scope. Otherwise `bot` fixture can't be
 # session. See https://github.com/pytest-dev/pytest-asyncio/issues/68 for more details.
 @pytest.fixture(scope="session")
@@ -311,7 +329,7 @@ def false_update(request):
     scope="session",
     params=[pytz.timezone, zoneinfo.ZoneInfo] if TEST_WITH_OPT_DEPS else [zoneinfo.ZoneInfo],
 )
-def _tz_implementation(request):  # noqa: PT005
+def _tz_implementation(request):
     # This fixture is used to parametrize the timezone fixture
     # This is similar to what @pyttest.mark.parametrize does but for fixtures
     # However, this is needed only internally for the `tzinfo` fixture, so we keep it private
@@ -331,3 +349,13 @@ def timezone(tzinfo):
 @pytest.fixture
 def tmp_file(tmp_path) -> Path:
     return tmp_path / uuid4().hex
+
+
+@pytest.fixture(scope="session")
+def dummy_message():
+    return make_message("dummy_message")
+
+
+@pytest.fixture(scope="session")
+def dummy_message_dict(dummy_message):
+    return dummy_message.to_dict()
