@@ -28,7 +28,7 @@ import pytest
 from telegram import Chat, Message, TelegramObject, Update, User
 from telegram.ext import ContextTypes, PersistenceInput, PicklePersistence
 from telegram.warnings import PTBUserWarning
-from tests.auxil.files import PROJECT_ROOT_PATH
+from tests.auxil.files import SOURCE_ROOT_PATH
 from tests.auxil.pytest_classes import make_bot
 from tests.auxil.slots import mro_slots
 
@@ -898,10 +898,9 @@ class TestPicklePersistence:
         assert len(recwarn) == 1
         assert recwarn[-1].category is PTBUserWarning
         assert str(recwarn[-1].message).startswith("Unknown bot instance found.")
-        assert (
-            Path(recwarn[-1].filename)
-            == PROJECT_ROOT_PATH / "telegram" / "ext" / "_picklepersistence.py"
-        ), "wrong stacklevel!"
+        assert Path(recwarn[-1].filename) == SOURCE_ROOT_PATH / "ext" / "_picklepersistence.py", (
+            "wrong stacklevel!"
+        )
         pp = PicklePersistence("pickletest", single_file=False, on_flush=False)
         pp.set_bot(bot)
         assert (await pp.get_chat_data())[12345]["unknown_bot_in_user"]._bot is None
