@@ -40,6 +40,7 @@ def chat_admin_rights():
         can_post_stories=True,
         can_edit_stories=True,
         can_delete_stories=True,
+        can_manage_direct_messages=True,
     )
 
 
@@ -67,6 +68,7 @@ class TestChatAdministratorRightsWithoutRequest:
             "can_post_stories": True,
             "can_edit_stories": True,
             "can_delete_stories": True,
+            "can_manage_direct_messages": True,
         }
         chat_administrator_rights_de = ChatAdministratorRights.de_json(json_dict, offline_bot)
         assert chat_administrator_rights_de.api_kwargs == {}
@@ -93,6 +95,7 @@ class TestChatAdministratorRightsWithoutRequest:
         assert admin_rights_dict["can_post_stories"] == car.can_post_stories
         assert admin_rights_dict["can_edit_stories"] == car.can_edit_stories
         assert admin_rights_dict["can_delete_stories"] == car.can_delete_stories
+        assert admin_rights_dict["can_manage_direct_messages"] == car.can_manage_direct_messages
 
     def test_equality(self):
         a = ChatAdministratorRights(
@@ -143,6 +146,7 @@ class TestChatAdministratorRightsWithoutRequest:
             True,
             True,
             True,
+            True,
         )
         t = ChatAdministratorRights.all_rights()
         # if the dirs are the same, the attributes will all be there
@@ -168,6 +172,7 @@ class TestChatAdministratorRightsWithoutRequest:
             False,
             False,
             False,
+            False,
         )
         t = ChatAdministratorRights.no_rights()
         # if the dirs are the same, the attributes will all be there
