@@ -62,9 +62,9 @@ class TestConstantsWithoutRequest:
             )
         }
         actual = set(constants.__all__)
-        assert (
-            actual == expected
-        ), f"Members {expected - actual} were not listed in constants.__all__"
+        assert actual == expected, (
+            f"Members {expected - actual} were not listed in constants.__all__"
+        )
 
     def test_message_attachment_type(self):
         assert all(
@@ -182,6 +182,7 @@ class TestConstantsWithoutRequest:
             "caption",
             "chat",
             "chat_id",
+            "direct_messages_topic",
             "effective_attachment",
             "entities",
             "from_user",
@@ -204,6 +205,8 @@ class TestConstantsWithoutRequest:
             "is_from_offline",
             "show_caption_above_media",
             "paid_star_count",
+            "is_paid_post",
+            "reply_to_checklist_task_id",
         }
 
     @pytest.mark.parametrize(
@@ -226,9 +229,9 @@ class TestConstantsWithoutRequest:
 
     @pytest.mark.parametrize("member", constants.MessageType)
     def test_message_type_completeness_reverse(self, member):
-        assert self.is_type_attribute(
-            member.value
-        ), f"Additional member {member} in MessageType that should not be a message type"
+        assert self.is_type_attribute(member.value), (
+            f"Additional member {member} in MessageType that should not be a message type"
+        )
 
     @pytest.mark.parametrize("member", constants.MessageAttachmentType)
     def test_message_attachment_type_completeness(self, member):
