@@ -60,8 +60,6 @@ class TestForumTopicWithoutRequest:
         assert forum_topic_object.icon_custom_emoji_id == emoji_id
 
     def test_de_json(self, offline_bot, emoji_id, forum_group_id):
-        assert ForumTopic.de_json(None, bot=offline_bot) is None
-
         json_dict = {
             "message_thread_id": forum_group_id,
             "name": TEST_TOPIC_NAME,
@@ -298,17 +296,15 @@ class TestForumTopicCreatedWithoutRequest:
     def test_slot_behaviour(self, topic_created):
         for attr in topic_created.__slots__:
             assert getattr(topic_created, attr, "err") != "err", f"got extra slot '{attr}'"
-        assert len(mro_slots(topic_created)) == len(
-            set(mro_slots(topic_created))
-        ), "duplicate slot"
+        assert len(mro_slots(topic_created)) == len(set(mro_slots(topic_created))), (
+            "duplicate slot"
+        )
 
     def test_expected_values(self, topic_created):
         assert topic_created.icon_color == TEST_TOPIC_ICON_COLOR
         assert topic_created.name == TEST_TOPIC_NAME
 
     def test_de_json(self, offline_bot):
-        assert ForumTopicCreated.de_json(None, bot=offline_bot) is None
-
         json_dict = {"icon_color": TEST_TOPIC_ICON_COLOR, "name": TEST_TOPIC_NAME}
         action = ForumTopicCreated.de_json(json_dict, offline_bot)
         assert action.api_kwargs == {}
@@ -395,8 +391,6 @@ class TestForumTopicEdited:
         assert topic_edited.icon_custom_emoji_id == emoji_id
 
     def test_de_json(self, bot, emoji_id):
-        assert ForumTopicEdited.de_json(None, bot=bot) is None
-
         json_dict = {"name": TEST_TOPIC_NAME, "icon_custom_emoji_id": emoji_id}
         action = ForumTopicEdited.de_json(json_dict, bot)
         assert action.api_kwargs == {}
