@@ -94,8 +94,6 @@ class TestGiveawayWithoutRequest:
         assert giveaway.premium_subscription_month_count == self.premium_subscription_month_count
         assert giveaway.prize_star_count == self.prize_star_count
 
-        assert Giveaway.de_json(None, offline_bot) is None
-
     def test_de_json_localization(self, tz_bot, offline_bot, raw_bot):
         json_dict = {
             "chats": [chat.to_dict() for chat in self.chats],
@@ -183,9 +181,9 @@ class TestGiveawayCreatedWithoutRequest:
     def test_slot_behaviour(self, giveaway_created):
         for attr in giveaway_created.__slots__:
             assert getattr(giveaway_created, attr, "err") != "err", f"got extra slot '{attr}'"
-        assert len(mro_slots(giveaway_created)) == len(
-            set(mro_slots(giveaway_created))
-        ), "duplicate slot"
+        assert len(mro_slots(giveaway_created)) == len(set(mro_slots(giveaway_created))), (
+            "duplicate slot"
+        )
 
     def test_de_json(self, bot):
         json_dict = {
@@ -196,8 +194,6 @@ class TestGiveawayCreatedWithoutRequest:
         assert gac.api_kwargs == {}
         assert gac.prize_star_count == self.prize_star_count
 
-        assert Giveaway.de_json(None, bot) is None
-
     def test_to_dict(self, giveaway_created):
         gac_dict = giveaway_created.to_dict()
 
@@ -242,9 +238,9 @@ class TestGiveawayWinnersWithoutRequest:
     def test_slot_behaviour(self, giveaway_winners):
         for attr in giveaway_winners.__slots__:
             assert getattr(giveaway_winners, attr, "err") != "err", f"got extra slot '{attr}'"
-        assert len(mro_slots(giveaway_winners)) == len(
-            set(mro_slots(giveaway_winners))
-        ), "duplicate slot"
+        assert len(mro_slots(giveaway_winners)) == len(set(mro_slots(giveaway_winners))), (
+            "duplicate slot"
+        )
 
     def test_de_json(self, offline_bot):
         json_dict = {
@@ -281,8 +277,6 @@ class TestGiveawayWinnersWithoutRequest:
         assert giveaway_winners.prize_description == self.prize_description
         assert giveaway_winners.prize_star_count == self.prize_star_count
 
-        assert GiveawayWinners.de_json(None, offline_bot) is None
-
     def test_de_json_localization(self, tz_bot, offline_bot, raw_bot):
         json_dict = {
             "chat": self.chat.to_dict(),
@@ -391,9 +385,9 @@ class TestGiveawayCompletedWithoutRequest:
     def test_slot_behaviour(self, giveaway_completed):
         for attr in giveaway_completed.__slots__:
             assert getattr(giveaway_completed, attr, "err") != "err", f"got extra slot '{attr}'"
-        assert len(mro_slots(giveaway_completed)) == len(
-            set(mro_slots(giveaway_completed))
-        ), "duplicate slot"
+        assert len(mro_slots(giveaway_completed)) == len(set(mro_slots(giveaway_completed))), (
+            "duplicate slot"
+        )
 
     def test_de_json(self, offline_bot):
         json_dict = {
@@ -411,8 +405,6 @@ class TestGiveawayCompletedWithoutRequest:
         assert giveaway_completed.giveaway_message == self.giveaway_message
         assert giveaway_completed.is_star_giveaway == self.is_star_giveaway
 
-        assert GiveawayCompleted.de_json(None, offline_bot) is None
-
     def test_to_dict(self, giveaway_completed):
         giveaway_completed_dict = giveaway_completed.to_dict()
 
