@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2024
+# Copyright (C) 2015-2025
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -25,14 +25,14 @@ from tests.auxil.slots import mro_slots
 
 @pytest.fixture(scope="module")
 def sent_web_app_message():
-    return SentWebAppMessage(inline_message_id=TestSentWebAppMessageBase.inline_message_id)
+    return SentWebAppMessage(inline_message_id=SentWebAppMessageTestBase.inline_message_id)
 
 
-class TestSentWebAppMessageBase:
+class SentWebAppMessageTestBase:
     inline_message_id = "123"
 
 
-class TestSentWebAppMessageWithoutRequest(TestSentWebAppMessageBase):
+class TestSentWebAppMessageWithoutRequest(SentWebAppMessageTestBase):
     def test_slot_behaviour(self, sent_web_app_message):
         inst = sent_web_app_message
         for attr in inst.__slots__:
@@ -45,7 +45,7 @@ class TestSentWebAppMessageWithoutRequest(TestSentWebAppMessageBase):
         assert isinstance(sent_web_app_message_dict, dict)
         assert sent_web_app_message_dict["inline_message_id"] == self.inline_message_id
 
-    def test_de_json(self, bot):
+    def test_de_json(self, offline_bot):
         data = {"inline_message_id": self.inline_message_id}
         m = SentWebAppMessage.de_json(data, None)
         assert m.api_kwargs == {}
