@@ -23,6 +23,7 @@ from copy import deepcopy
 import pytest
 
 from telegram import (
+    BusinessBotRights,
     BusinessConnection,
     BusinessMessagesDeleted,
     CallbackQuery,
@@ -47,6 +48,7 @@ from telegram import (
     PreCheckoutQuery,
     ReactionCount,
     ReactionTypeEmoji,
+    ShippingAddress,
     ShippingQuery,
     Update,
     User,
@@ -128,7 +130,7 @@ business_connection = BusinessConnection(
     1,
     from_timestamp(int(time.time())),
     True,
-    True,
+    rights=BusinessBotRights(can_reply=True),
 )
 
 deleted_business_messages = BusinessMessagesDeleted(
@@ -158,7 +160,11 @@ params = [
     {"edited_channel_post": channel_post},
     {"inline_query": InlineQuery(1, User(1, "", False), "", "")},
     {"chosen_inline_result": ChosenInlineResult("id", User(1, "", False), "")},
-    {"shipping_query": ShippingQuery("id", User(1, "", False), "", None)},
+    {
+        "shipping_query": ShippingQuery(
+            "id", User(1, "", False), "", ShippingAddress("", "", "", "", "", "")
+        )
+    },
     {"pre_checkout_query": PreCheckoutQuery("id", User(1, "", False), "", 0, "")},
     {"poll": Poll("id", "?", [PollOption(".", 1)], False, False, False, Poll.REGULAR, True)},
     {
@@ -252,11 +258,6 @@ class TestUpdateWithoutRequest(UpdateTestBase):
                 assert getattr(update, _type) == paramdict[_type]
         assert i == 1
 
-    def test_update_de_json_empty(self, offline_bot):
-        update = Update.de_json(None, offline_bot)
-
-        assert update is None
-
     def test_to_dict(self, update):
         update_dict = update.to_dict()
 
