@@ -343,9 +343,9 @@ class TestUserWithoutRequest(UserTestBase):
             "title",
             "description",
             "payload",
-            "provider_token",
             "currency",
             "prices",
+            "provider_token",
         )
 
     async def test_instance_method_send_location(self, monkeypatch, user):
@@ -731,8 +731,10 @@ class TestUserWithoutRequest(UserTestBase):
                 and kwargs["text_entities"] == "text_entities"
             )
 
-        assert check_shortcut_signature(user.send_gift, Bot.send_gift, ["user_id"], [])
-        assert await check_shortcut_call(user.send_gift, user.get_bot(), "send_gift")
+        assert check_shortcut_signature(user.send_gift, Bot.send_gift, ["user_id", "chat_id"], [])
+        assert await check_shortcut_call(
+            user.send_gift, user.get_bot(), "send_gift", ["chat_id", "user_id"]
+        )
         assert await check_defaults_handling(user.send_gift, user.get_bot())
 
         monkeypatch.setattr(user.get_bot(), "send_gift", make_assertion)
@@ -743,6 +745,36 @@ class TestUserWithoutRequest(UserTestBase):
             text_entities="text_entities",
         )
 
+    async def test_instance_method_gift_premium_subscription(self, monkeypatch, user):
+        async def make_assertion(*_, **kwargs):
+            return (
+                kwargs["user_id"] == user.id
+                and kwargs["month_count"] == 3
+                and kwargs["star_count"] == 1000
+                and kwargs["text"] == "text"
+                and kwargs["text_parse_mode"] == "text_parse_mode"
+                and kwargs["text_entities"] == "text_entities"
+            )
+
+        assert check_shortcut_signature(
+            user.gift_premium_subscription, Bot.gift_premium_subscription, ["user_id"], []
+        )
+        assert await check_shortcut_call(
+            user.gift_premium_subscription,
+            user.get_bot(),
+            "gift_premium_subscription",
+        )
+        assert await check_defaults_handling(user.gift_premium_subscription, user.get_bot())
+
+        monkeypatch.setattr(user.get_bot(), "gift_premium_subscription", make_assertion)
+        assert await user.gift_premium_subscription(
+            month_count=3,
+            star_count=1000,
+            text="text",
+            text_parse_mode="text_parse_mode",
+            text_entities="text_entities",
+        )
+
     async def test_instance_method_verify_user(self, monkeypatch, user):
         async def make_assertion(*_, **kwargs):
             return (
